
pypocketfft version
-------------------

SciPy currently vendors [pypocketfft] at:

    commit bf2c431c21213b7c5e23c2f542009b0bd3ec1445
    Merge: 8234f5c 9c252b2
    Author: Martin Reinecke <martin@mpa-garching.mpg.de>
    Date:   Tue Oct 20 15:16:14 2020 +0200

        Merge branch 'good_size_keywords' into 'master'

        Handle keyword args in good_size

        See merge request mtr/pypocketfft!41

pypocketfft: https://gitlab.mpcdf.mpg.de/mtr/pypocketfft
